==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ClusterNetworkEntryFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ClusterNetworkEntryFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.ClusterNetworkEntryFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.ClusterNetworkEntryFluent<A>{
  public ClusterNetworkEntryFluentImpl() {
  }
  public ClusterNetworkEntryFluentImpl(io.fabric8.openshift.api.model.operator.v1.ClusterNetworkEntry instance) {
    this.withCidr(instance.getCidr()); 
    this.withHostPrefix(instance.getHostPrefix()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String cidr;
  private java.lang.Integer hostPrefix;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getCidr() {
    return this.cidr;
  }
  public A withCidr(java.lang.String cidr) {
    this.cidr=cidr; return (A) this;
  }
  public java.lang.Boolean hasCidr() {
    return this.cidr != null;
  }
  
  /**
   * Method is deprecated. use withCidr instead.
   */
  @java.lang.Deprecated
  public A withNewCidr(java.lang.String arg0) {
    return (A)withCidr(new String(arg0));
  }
  public java.lang.Integer getHostPrefix() {
    return this.hostPrefix;
  }
  public A withHostPrefix(java.lang.Integer hostPrefix) {
    this.hostPrefix=hostPrefix; return (A) this;
  }
  public java.lang.Boolean hasHostPrefix() {
    return this.hostPrefix != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClusterNetworkEntryFluentImpl that = (ClusterNetworkEntryFluentImpl) o;
    if (cidr != null ? !cidr.equals(that.cidr) :that.cidr != null) return false;
    if (hostPrefix != null ? !hostPrefix.equals(that.hostPrefix) :that.hostPrefix != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cidr,  hostPrefix,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/ClusterNetworkEntryFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ClusterNetworkEntryFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.ClusterNetworkEntryFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.ClusterNetworkEntryFluent<A>{
  public ClusterNetworkEntryFluentImpl() {
  }
  public ClusterNetworkEntryFluentImpl(io.fabric8.openshift.api.model.operator.v1.ClusterNetworkEntry instance) {
    this.withCidr(instance.getCidr()); 
    this.withHostPrefix(instance.getHostPrefix()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String cidr;
  private java.lang.Integer hostPrefix;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getCidr() {
    return this.cidr;
  }
  public A withCidr(java.lang.String cidr) {
    this.cidr=cidr; return (A) this;
  }
  public java.lang.Boolean hasCidr() {
    return this.cidr != null;
  }
  
  /**
   * Method is deprecated. use withCidr instead.
   */
  @java.lang.Deprecated
  public A withNewCidr(java.lang.String arg0) {
    return (A)withCidr(new String(arg0));
  }
  public java.lang.Integer getHostPrefix() {
    return this.hostPrefix;
  }
  public A withHostPrefix(java.lang.Integer hostPrefix) {
    this.hostPrefix=hostPrefix; return (A) this;
  }
  public java.lang.Boolean hasHostPrefix() {
    return this.hostPrefix != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClusterNetworkEntryFluentImpl that = (ClusterNetworkEntryFluentImpl) o;
    if (cidr != null ? !cidr.equals(that.cidr) :that.cidr != null) return false;
    if (hostPrefix != null ? !hostPrefix.equals(that.hostPrefix) :that.hostPrefix != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cidr,  hostPrefix,  additionalProperties,  super.hashCode());
  }
  
}
